@@ -13,6 +13,7 @@ from requests.exceptions import RequestException
 from tqdm.contrib.concurrent import thread_map
 from werkzeug.utils import secure_filename
 
+from plagdef.config import settings
 from plagdef.model.models import Document, File
 
 log = logging.getLogger(__name__)
@@ -34,8 +35,8 @@ def download_external_sources(doc: Document, target_dir: Path) -> set[File]:
 
 def _download_page(url: str, target_dir: Path) -> File:
     parsed_url = urlparse(url)
-    filename = parsed_url.netloc if not parsed_url.path else \
-        f'{parsed_url.path.rstrip("/")[parsed_url.path.rstrip("/").rindex("/") + 1:]}_from_{parsed_url.netloc}'
+    url_path = parsed_url.path.rstrip("/")
+    filename = parsed_url.netloc if not url_path else f'{url_path[url_path.rindex("/") + 1:]}_from_{parsed_url.netloc}'
     filename = secure_filename(filename)
     try:
         resp = requests.get(url)
@@ -47,7 +48,8 @@ def _download_page(url: str, target_dir: Path) -> File:
         if mime_type.startswith("text/html"):
             content = BeautifulSoup(resp.text, features="lxml").get_text(" ", True)
             ext = ".txt"
-        file = File(Path(f"{target_dir}/{filename}{ext}"), content, binary) if len(content) else None
+        file = File(Path(f"{target_dir}/{filename}{ext}"), content, binary) \
+            if len(content) >= settings['min_ext_size'] else None
         return file
     except RequestException:
         log.debug(f'Could not download from "{url}".')
